@@ -23,14 +23,14 @@
 #include "statistictablemodel.h"
 
 // Okteta core
-#include <character.h>
-#include <charcodec.h>
-#include <valuecodec.h>
+#include <okteta/character.h>
+#include <okteta/charcodec.h>
+#include <okteta/valuecodec.h>
 // KF5
 #include <KLocalizedString>
 #include <KColorScheme>
 // Qt
-#include <QtWidgets/QApplication>
+#include <QApplication>
 
 
 namespace Kasten
